@@ -19,13 +19,14 @@ sub generator {
 
 sub get {
     my ($self, $id) = @_;
-    my $field_list = [];
+    my $field_list = $self->store->_field_list;
     my $api = Catmandu::CA::API->new(
         url        => $self->store->url,
         username   => $self->store->username,
-        password   => $self->store->password
+        password   => $self->store->password,
+        lang       => $self->store->lang
     );
-    return $api->simple($id);
+    return $api->id($id, $field_list);
 }
 
 sub add {
@@ -33,7 +34,8 @@ sub add {
     my $api = Catmandu::CA::API->new(
         url        => $self->store->url,
         username   => $self->store->username,
-        password   => $self->store->password
+        password   => $self->store->password,
+        lang       => $self->store->lang
     );
     return $api->add($data);
 }
@@ -43,7 +45,8 @@ sub update {
     my $api = Catmandu::CA::API->new(
         url        => $self->store->url,
         username   => $self->store->username,
-        password   => $self->store->password
+        password   => $self->store->password,
+        lang       => $self->store->lang
     );
     return $api->update($id, $data);
 }
@@ -53,7 +56,8 @@ sub delete {
     my $api = Catmandu::CA::API->new(
         url        => $self->store->url,
         username   => $self->store->username,
-        password   => $self->store->password
+        password   => $self->store->password,
+        lang       => $self->store->lang
     );
     return $api->delete($id);
 }
